# cross_framework_hpo
Exploration of cross framework model divergence through hyperparameter optimization


Base code which was used to run the experiments which generated with initial CrossedWires dataset (https://github.com/maxzvyagin/crossedwires)
